VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "clsLabel3D"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
' ***********************************************************
' *
' *   3D Label (Klasse)
' *
' *   Diese Klasse zeichnet ein 3D Label auf einer Form.
' *   Bentigt werden zwei Label-Controls auf der
' *   aufrufenden Form. Die Labels werden der Prozedure
' *   "Init" bergeben. Optional kann ein drittes Label
' *   als MidLabel bergeben werden.
' *
' *   Eigenschaften:
' *     - LabelForeColor (Default: vb3DHighlight)
' *     - LabelBackColor (Default: vb3DDKShadow)
' *     - Optional MidBackColor (Default: vb3DShadow)
' *     - TopGap (Schattenversatz Oben, Default: 30 Twips)
' *     - LeftGap (Schattenversatz Links, Default: 30 Twips)
' *     - ShadowPos (Schattenposition, Enum ShadowFrom)
' *
' *   Dezember 2003, VB-Power.net & Roland Wutzke
' *   http://www.vb-power.net
' *   mailto:snoopy@vb-power.net
' *
' ***********************************************************

Option Explicit

' Eigenschaften der Klasse
Public LabelForeColor As OLE_COLOR
Public LabelBackColor As OLE_COLOR
Public LabelMidColor As OLE_COLOR
Public TopGap As Long
Public LeftGap As Long
Public ShadowPos As ShadowFrom

' Position des BackLabel
Public Enum ShadowFrom
  LinksOben
  MitteOben
  RechtsOben
  RechtsMitte
  LinksMitte
  LinksUnten
  MitteUnten
  RechtsUnten
End Enum

Private Sub Class_Initialize()
  ' Eigenschaften vorbesetzen
  LabelForeColor = vb3DHighlight
  LabelBackColor = vb3DDKShadow
  LabelMidColor = vb3DShadow
  TopGap = 30
  LeftGap = 30
  ShadowPos = LinksMitte
End Sub

Public Sub Init(ForeLabel As Label, BackLabel As Label, _
  Optional MidLabel As Label)
                
  Dim ForeTop As Long
  Dim ForeLeft As Long
  Dim MTopGap As Long
  Dim MLeftGap As Long
   
  ' Top und Left in Variable retten
  ForeTop = ForeLabel.Top
  ForeLeft = ForeLabel.Left
  MTopGap = TopGap \ 2
  MLeftGap = LeftGap \ 2
   
  ' Farben setzen
  ForeLabel.ForeColor = LabelForeColor
  BackLabel.ForeColor = LabelBackColor
   
  ' BackStyle setzen
  ForeLabel.BackStyle = vbTransparent
  BackLabel.BackStyle = vbTransparent

  ' Schatten positionieren
  With BackLabel
    Select Case ShadowPos
      Case LinksOben
        .Top = ForeTop - TopGap
        .Left = ForeLeft - LeftGap
      Case MitteOben
        .Top = ForeTop - TopGap
        .Left = ForeLeft
      Case RechtsOben
        .Top = ForeTop - TopGap
        .Left = ForeLeft + LeftGap
      Case RechtsMitte
        .Top = ForeTop
        .Left = ForeLeft + LeftGap
      Case LinksMitte
        .Top = ForeTop
        .Left = ForeLeft - LeftGap
      Case LinksUnten
        .Top = ForeTop + TopGap
        .Left = ForeLeft - LeftGap
      Case MitteUnten
        .Top = ForeTop + TopGap
        .Left = ForeLeft
      Case RechtsUnten
        .Top = ForeTop + TopGap
        .Left = ForeLeft + LeftGap
    End Select
  End With
   
  ' MidLabel vorhanden, dann Anzeigen
  If Not MidLabel Is Nothing Then
   
    ' Farbe MidLabel setzen
    MidLabel.ForeColor = LabelMidColor
      
    ' BackStyle setzen
    MidLabel.BackStyle = vbTransparent
      
    ' In den Hintergrund schieben
    MidLabel.ZOrder 1
            
    ' Schatten positionieren
    With MidLabel
      Select Case ShadowPos
        Case LinksOben
          .Top = ForeTop - MTopGap
          .Left = ForeLeft - MLeftGap
        Case MitteOben
          .Top = ForeTop - MTopGap
          .Left = ForeLeft
        Case RechtsOben
          .Top = ForeTop - MTopGap
          .Left = ForeLeft + MLeftGap
        Case RechtsMitte
          .Top = ForeTop
          .Left = ForeLeft + MLeftGap
        Case LinksMitte
          .Top = ForeTop
          .Left = ForeLeft - MLeftGap
        Case LinksUnten
          .Top = ForeTop + MTopGap
          .Left = ForeLeft - MLeftGap
        Case MitteUnten
          .Top = ForeTop + MTopGap
          .Left = ForeLeft
        Case RechtsUnten
          .Top = ForeTop + MTopGap
          .Left = ForeLeft + MLeftGap
      End Select
    End With
  End If

  ' Wichtig!!! Label Reihenfolge setzen
  ForeLabel.ZOrder 0
  BackLabel.ZOrder 1
End Sub
